@@ -22,12 +22,6 @@ def check_raw_clock(d) -> None:
     if type(d) != dict:
         raise ValueError("clock file err: doesn't mean dict.")
 
-    if "message" not in d:
-        raise ValueError("clock file err: doesn't include message property.")
-
-    if type(d["message"]) != str:
-        raise ValueError(f"clock file err: {d['message']} is not str object.")
-
     if "sounds" not in d:
         raise ValueError("clock file err: doesn't include sounds property.")
 
@@ -35,7 +29,6 @@ def check_raw_clock(d) -> None:
         raise ValueError("clock file err: sounds is not dict object.")
 
     # sound["n"]はdict
-    # soundsのmessageがある
     # soundsのmessageは文字列型
     # sounds_filenameがある
     # sounds_filenameの値は文字列
